==> apache-jmeter-4.0_src.zip: apache-jmeter-4.0/src/protocol/jms/org/apache/jmeter/protocol/jms/sampler/render/FileKey.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jmeter.protocol.jms.sampler.render;

import java.util.Objects;

/** File specification for {@link TextMessageRenderer} **/
class FileKey {

    private final String filename;
    private final String encoding;

    public FileKey(String filename, String encoding) {
        this.filename = filename;
        this.encoding = encoding;
    }

    public String getFilename() {
        return filename;
    }

    public String getEncoding() {
        return encoding;
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(filename);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (!(obj instanceof FileKey)) {
            return false;
        }

        FileKey that = (FileKey) obj;

        return Objects.equals(this.filename, that.filename);

    }
}

==> apache-jmeter-5.0_src.zip: apache-jmeter-5.0/src/protocol/jms/org/apache/jmeter/protocol/jms/sampler/render/FileKey.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jmeter.protocol.jms.sampler.render;

import java.util.Objects;

/** File specification for TextMessageRenderer **/
class FileKey {

    private final String filename;
    private final String encoding;

    public FileKey(String filename, String encoding) {
        this.filename = filename;
        this.encoding = encoding;
    }

    public String getFilename() {
        return filename;
    }

    public String getEncoding() {
        return encoding;
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(filename);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (!(obj instanceof FileKey)) {
            return false;
        }

        FileKey that = (FileKey) obj;

        return Objects.equals(this.filename, that.filename);

    }
}
